.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on pypi or github. It is a comment.

=============
iaweb.privacy
=============

This package implement collective.privacy rules for IMIO web projects


Installation
------------

Install iaweb.privacy by adding it to your buildout::

    [buildout]

    ...

    eggs =
        iaweb.privacy


and then running ``bin/buildout``


Contribute
----------

- Issue Tracker: https://github.com/collective/iaweb.privacy/issues
- Source Code: https://github.com/collective/iaweb.privacy


License
-------

The project is licensed under the GPLv2.
